@@ -174,10 +174,13 @@ class CodeBlock(VGroup):
             self.title_background = lang_background
 
             super().__init__(background_rect, markup, lang_background, lang_name, **kwargs)
-        else: super().__init__(background_rect, markup, **kwargs)
+        else: 
+            self.title = None
+            self.title_background = None
+            super().__init__(background_rect, markup, **kwargs)
 
         self.code = markup
-        self.title = lang_name
+        self.code_background = background_rect
 
     def create(self, **kwargs) -> tuple[FadeIn, AddTextLetterByLetter, FadeIn, AddTextLetterByLetter]:
         """
@@ -188,7 +191,7 @@ class CodeBlock(VGroup):
         ```
         By default the animation will `FadeIn` the `background` and `title_background`, and `AddTextLetterByLetter` the `code` and `title`. 
         """
-        if self.title and self.title_background: return (
+        if getattr(self, 'title', None) and getattr(self, 'title_background', None): return (
             FadeIn(self.code_background, **kwargs), 
             AddTextLetterByLetter(self.code, **kwargs), 
             FadeIn(self.title_background, **kwargs), 
@@ -209,7 +212,7 @@ class CodeBlock(VGroup):
         ```
         By default the animation will `FadeOut` the `background` and `title_background`, and `Uncreate` the `code` and `title`. 
         """
-        if self.title and self.title_background: return (
+        if getattr(self, 'title', None) and getattr(self, 'title_background', None): return (
             FadeOut(self.code_background, **kwargs), 
             Uncreate(self.code, **kwargs), 
             FadeOut(self.title_background, **kwargs), 
